Unnamed repository; edit this file 'description' to name the repository.
Diffstat (limited to 'crates/hir-ty/src/mir/eval/tests.rs')
-rw-r--r--crates/hir-ty/src/mir/eval/tests.rs21
1 files changed, 15 insertions, 6 deletions
diff --git a/crates/hir-ty/src/mir/eval/tests.rs b/crates/hir-ty/src/mir/eval/tests.rs
index 82c0a8070c..4eb4aa9159 100644
--- a/crates/hir-ty/src/mir/eval/tests.rs
+++ b/crates/hir-ty/src/mir/eval/tests.rs
@@ -4,15 +4,20 @@ use span::Edition;
use syntax::{TextRange, TextSize};
use test_fixture::WithFixture;
-use crate::display::DisplayTarget;
use crate::{
- Interner, Substitution, db::HirDatabase, mir::MirLowerError, setup_tracing, test_db::TestDB,
+ db::HirDatabase,
+ display::DisplayTarget,
+ mir::MirLowerError,
+ next_solver::{DbInterner, GenericArgs},
+ setup_tracing,
+ test_db::TestDB,
};
use super::{MirEvalError, interpret_mir};
fn eval_main(db: &TestDB, file_id: EditionedFileId) -> Result<(String, String), MirEvalError<'_>> {
crate::attach_db(db, || {
+ let interner = DbInterner::new_with(db, None, None);
let module_id = db.module_for_file(file_id.file_id(db));
let def_map = module_id.def_map(db);
let scope = &def_map[module_id.local_id].scope;
@@ -34,7 +39,7 @@ fn eval_main(db: &TestDB, file_id: EditionedFileId) -> Result<(String, String),
let body = db
.monomorphized_mir_body(
func_id.into(),
- Substitution::empty(Interner),
+ GenericArgs::new_from_iter(interner, []),
db.trait_environment(func_id.into()),
)
.map_err(|e| MirEvalError::MirLowerError(func_id, e))?;
@@ -631,11 +636,16 @@ fn main() {
);
}
+#[ignore = "
+FIXME(next-solver):
+This does not work currently because I replaced homemade selection with selection by the trait solver;
+This will work once we implement `Interner::impl_specializes()` properly.
+"]
#[test]
fn specialization_array_clone() {
check_pass(
r#"
//- minicore: copy, derive, slice, index, coerce_unsized
impl<T: Clone, const N: usize> Clone for [T; N] {
#[inline]
fn clone(&self) -> Self {
@@ -650,8 +660,7 @@ trait SpecArrayClone: Clone {
impl<T: Clone> SpecArrayClone for T {
#[inline]
default fn clone<const N: usize>(array: &[T; N]) -> [T; N] {
- // FIXME: panic here when we actually implement specialization.
- from_slice(array)
+ panic!("should go to the specialized impl")
}
}
@@ -631,11 +636,16 @@ fn main() {
check_pass(
r#"
-//- minicore: copy, derive, slice, index, coerce_unsized
+//- minicore: copy, derive, slice, index, coerce_unsized, panic
impl<T: Clone, const N: usize> Clone for [T; N] {
#[inline]